%define anolis_release 3
Name:           shadow
Version:        4.14.3
Release:        %{anolis_release}%{?dist}
Summary:        Utilities for managing accounts and shadow password files

License:        BSD and GPLv2+
URL:            https://github.com/shadow-maint/shadow
Source0:        https://github.com/shadow-maint/shadow/archive/refs/tags/%{version}.tar.gz
Source1:        shadow.useradd
Source2:        shadow.login.defs
Source3:        shadow-bsd.txt
Source4: 	https://www.gnu.org/licenses/old-licenses/gpl-2.0.txt
Source5: 	shadow-utils.HOME_MODE.xml
Source6: 	passwd.pamd

### Globals ###
%global includesubiddir %{_includedir}/shadow

BuildRequires:  audit-libs-devel >= 1.6.5
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  docbook-dtds
BuildRequires:  docbook-style-xsl
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  gettext-devel
BuildRequires:  itstool
BuildRequires:  libbsd-devel
BuildRequires:  libselinux-devel >= 1.25.2-1
BuildRequires:  libsemanage-devel
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  make
BuildRequires:  pkgconf
BuildRequires: pam-devel

Requires: audit-libs >= 1.6.5
Requires: libselinux >= 1.25.2-1
Requires: pam-libs
Requires: setup

Provides: shadow-utils = %{version}-%{release}

%description
The shadow package includes the necessary programs for
converting UNIX password files to the shadow password format, plus
programs for managing user and group accounts. The pwconv command
converts passwords to the shadow password format. The pwunconv command
unconverts shadow passwords and generates a passwd file (a standard
UNIX password file). The pwck command checks the integrity of password
and shadow files. The lastlog command prints out the last login times
for all users. The useradd, userdel, and usermod commands are used for
managing user accounts. The groupadd, groupdel, and groupmod commands
are used for managing group accounts.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package subid
Summary: A library to manage subordinate uid and gid ranges
License: BSD and GPLv2+

%description subid
Utility library that provides a way to manage subid ranges.

%package utils-subid
Summary: A library to manage subordinate uid and gid ranges
License: BSD and GPLv2+

%description utils-subid
Utility library that provides a way to manage subid ranges.

%package subid-devel
Summary: Development package for shadow-subid
License: BSD and GPLv2+
Requires: shadow-subid

%description subid-devel
Development files for shadow-subid.

%package utils-subid-devel
Summary: Development package for shadow-utils-subid
License: BSD and GPLv2+
Requires: shadow-utils-subid

%description utils-subid-devel
Development files for shadow-utils-subid.

%prep
%autosetup -p1 -n shadow-%{version}

iconv -f ISO88591 -t utf-8  doc/HOWTO > doc/HOWTO.utf8
cp -f doc/HOWTO.utf8 doc/HOWTO

cp -a %{SOURCE3} %{SOURCE4} .
cp -a %{SOURCE5} man/login.defs.d/HOME_MODE.xml

%build
export CFLAGS="$RPM_OPT_FLAGS -fpie"
export LDFLAGS="-pie -Wl,-z,relro -Wl,-z,now"
autoreconf -v -f --install || exit 1

%configure \
        --enable-shadowgrp \
        --enable-man \
        --with-audit \
        --with-sha-crypt \
        --with-bcrypt \
        --with-yescrypt \
        --with-selinux \
        --without-libcrack \
        --without-libpam \
        --enable-shared \
        --with-group-name-max-length=32
%make_build

%install
%make_install gnulocaledir=$RPM_BUILD_ROOT%{_datadir}/locale MKINSTALLDIRS=`pwd`/mkinstalldirs
install -d -m 755 $RPM_BUILD_ROOT%{_sysconfdir}/default
install -p -c -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/login.defs
install -p -c -m 0600 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/default/useradd


ln -s useradd $RPM_BUILD_ROOT%{_sbindir}/adduser
ln -s useradd.8 $RPM_BUILD_ROOT%{_mandir}/man8/adduser.8
for subdir in $RPM_BUILD_ROOT%{_mandir}/{??,??_??,??_??.*}/man* ; do
        test -d $subdir && test -e $subdir/useradd.8 && echo ".so man8/useradd.8" > $subdir/adduser.8
done

rm $RPM_BUILD_ROOT%{_bindir}/{chfn,chsh,expiry,groups,login,passwd,su,faillog}
rm $RPM_BUILD_ROOT%{_sbindir}/{logoutd,nologin}
rm $RPM_BUILD_ROOT%{_sysconfdir}/{login.access,limits}
find $RPM_BUILD_ROOT%{_mandir} -type f -regex '.*man.*\/\(chfn\|chsh\|login\.access\|expiry\|groups\|login\|passwd\|su\|limits\|porttime\|suauth\|logoutd\|nologin\|getspnam\|faillog\)\.[1-9].*' -print -delete
find $RPM_BUILD_ROOT%{_mandir} -depth -type d -empty -delete

%find_lang shadow
for dir in $(ls -1d $RPM_BUILD_ROOT%{_mandir}/{??,??_??}) ; do
    dir=$(echo $dir | sed -e "s|^$RPM_BUILD_ROOT||")
    lang=$(basename $dir)
    echo "%%lang($lang) $dir/man*/*" >> shadow.filelist
done

# Move header files to its own folder
mkdir -p $RPM_BUILD_ROOT/%{includesubiddir}
install -m 644 libsubid/subid.h $RPM_BUILD_ROOT/%{includesubiddir}/

rm -f $RPM_BUILD_ROOT/%{_libdir}/libsubid.{la,a}
rm -f $RPM_BUILD_ROOT/%{_datadir}/locale/*/LC_MESSAGES/shadow.mo


%generate_compatibility_deps

%files -f shadow.filelist
%dir %{abidir}
%license gpl-2.0.txt shadow-bsd.txt
%attr(0644,root,root)   %config(noreplace) %{_sysconfdir}/login.defs
%attr(0644,root,root)   %config(noreplace) %{_sysconfdir}/default/useradd
%{_bindir}/sg
%attr(4755,root,root) %{_bindir}/chage
%attr(4755,root,root) %{_bindir}/gpasswd
%attr(4755,root,root) %{_bindir}/newgrp
%attr(0755,root,root) %caps(cap_setgid=ep) %{_bindir}/newgidmap
%attr(0755,root,root) %caps(cap_setuid=ep) %{_bindir}/newuidmap
%{_sbindir}/adduser
%attr(0755,root,root)   %{_sbindir}/user*
%attr(0755,root,root)   %{_sbindir}/group*
%{_sbindir}/grpck
%{_sbindir}/pwck
%{_sbindir}/*conv
%{_sbindir}/chpasswd
%{_sbindir}/chgpasswd
%{_sbindir}/newusers
%{_sbindir}/vipw
%{_sbindir}/vigr
%{abidir}/*-option.list
%{_mandir}/man1/chage.1*
%{_mandir}/man1/gpasswd.1*
%{_mandir}/man1/sg.1*
%{_mandir}/man1/newgrp.1*
%{_mandir}/man1/newgidmap.1*
%{_mandir}/man1/newuidmap.1*
%{_mandir}/man3/shadow.3*
%{_mandir}/man5/shadow.5*
%{_mandir}/man5/login.defs.5*
%{_mandir}/man5/gshadow.5*
%{_mandir}/man5/subuid.5*
%{_mandir}/man5/subgid.5*
%{_mandir}/man8/adduser.8*
%{_mandir}/man8/group*.8*
%{_mandir}/man8/user*.8*
%{_mandir}/man8/pwck.8*
%{_mandir}/man8/grpck.8*
%{_mandir}/man8/chpasswd.8*
%{_mandir}/man8/chgpasswd.8*
%{_mandir}/man8/newusers.8*
%{_mandir}/man8/*conv.8*
%{_mandir}/man8/vipw.8*
%{_mandir}/man8/vigr.8*

%files doc
%doc NEWS doc/HOWTO README

%files subid
%{_libdir}/libsubid.so.*
%{abidir}/libsubid*.dump
%{_bindir}/getsubids
%{_mandir}/man1/getsubids.1*

%files subid-devel
%{_includedir}/shadow/subid.h
%{_libdir}/libsubid.so


%changelog
* Thu May 09 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.14.3-3
- add packages

* Tue May 07 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.14.3-2
- add provides

* Thu Mar 14 2024 Kaiqiang Wang <wangkaiqiang@inspur.com> - 4.14.3-1
- update to 4.14.3

* Wed Oct 18 2023 Xiaoping Liu <lxp01404969@alibaba-inc.com> - 4.13-3
- Fix CVE-2023-4641

* Wed Feb 22 2023 Shawn Wang <shawnwang@linux.alibaba.com> - 4.13-2
- fix some bugs for 4.13

* Sun Jan 08 2023 Shawn Wang <shawnwang@linux.alibaba.com> - 4.13-1
- update to 4.13
- remove some unused build requires
- add some patches from upstream

* Fri Oct 28 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 4.12.3-4
- chage: Fix regression in print_date

* Thu Oct 13 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.12.3-3
- optimise spec file

* Fri Sep 30 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.12.3-2
- add nologin patch

* Fri Sep 23 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.12.3-1
- update to 4.12.3

* Thu Mar 24 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 4.11.1-3
- fix /etc/login.defs wrong content

* Fri Mar 18 2022 forrest_ly <flin@linux.alibaba.com> - 4.11.1-2
- Add upstream patches

* Wed Mar  2 2022 forrest_ly <flin@linux.alibaba.com> - 4.11.1-1
- Init for Anolis OS 23
